Geocoder2Exception class
Exception thrown when a geocoding request fails.
- Implemented types
Constructors
- Geocoder2Exception(String message, {String? status, int? statusCode})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A human-readable description of the error.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String?
-
The Google Maps Geocoding API status string (e.g. 'REQUEST_DENIED', 'ZERO_RESULTS', 'OVER_QUERY_LIMIT').
final
- statusCode → int?
-
The HTTP status code (e.g. 200, 400, 403, 500), if applicable.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited